import logging
from datetime import datetime
from telegram import Update
from telegram.ext import ContextTypes
from .base import InfoCommandsBase
from .utils import normalize_token_case
from src.config.config import Config
from src.utils.token_display_formatter import get_formatter

logger = logging.getLogger(__name__)

class PerformanceCommands(InfoCommandsBase):
    """Handles all performance-related commands."""

    async def performance_command(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
        """Handle the /performance command to show performance information."""
        if not self._is_authorized(update):
            return

        try:
            # Check if a specific token was requested
            args = context.args
            token = args[0].upper() if args else None

            stats = self.trading_engine.get_stats()
            if not stats:
                await self._reply(update, "❌ Could not load trading statistics")
                return

            if token:
                await self._show_token_performance(update, token, stats)
            else:
                await self._show_performance_ranking(update, stats)

        except Exception as e:
            error_message = f"❌ Error processing performance command: {str(e)}"
            await self._reply(update, error_message)
            logger.error(f"Error in performance command: {e}")

    async def _show_performance_ranking(self, update: Update, stats) -> None:
        """Show performance ranking for all tokens."""
        try:
            # Get performance data for all tokens
            token_performance = stats.get_token_performance()
            if not token_performance:
                await self._reply(update, "📊 No performance data available yet")
                return

            # Sort tokens by P&L
            sorted_tokens = sorted(
                token_performance,
                key=lambda x: x.get('total_pnl', 0),
                reverse=True
            )

            formatter = get_formatter()
            performance_text = ["📊 <b>Token Performance Ranking</b>"]

            for data in sorted_tokens:
                token = data.get('token', 'Unknown')
                total_pnl = data.get('total_pnl', 0)
                total_trades = data.get('total_trades', 0)
                win_rate = data.get('win_rate', 0)
                
                if total_trades > 0:
                    pnl_emoji = "🟢" if total_pnl >= 0 else "🔴"
                    performance_text.append(
                        f"\n<b>{token}</b>: {pnl_emoji} {formatter.format_price_with_symbol(total_pnl)} "
                        f"({total_trades} trades, {win_rate:.1f}% win rate)"
                    )

            await self._reply(update, "\n".join(performance_text))

        except Exception as e:
            error_message = f"❌ Error showing performance ranking: {str(e)}"
            await self._reply(update, error_message)
            logger.error(f"Error in _show_performance_ranking: {e}")

    async def _show_token_performance(self, update: Update, token: str, stats) -> None:
        """Show detailed performance for a specific token."""
        try:
            # Get performance data for the token
            token_performance = stats.get_token_performance(token)
            if not token_performance:
                await self._reply(update, f"📊 No performance data available for {token}")
                return

            formatter = get_formatter()
            performance_text = [f"📊 <b>{token} Performance</b>"]

            # Add summary statistics
            total_pnl = token_performance.get('total_pnl', 0)
            total_trades = token_performance.get('total_trades', 0)
            win_rate = token_performance.get('win_rate', 0)
            avg_trade = token_performance.get('avg_trade', 0)
            largest_win = token_performance.get('largest_win', 0)
            largest_loss = token_performance.get('largest_loss', 0)

            pnl_emoji = "🟢" if total_pnl >= 0 else "🔴"
            performance_text.extend([
                f"\n<b>Summary:</b>",
                f"• Total P&L: {pnl_emoji} {formatter.format_price_with_symbol(total_pnl)}",
                f"• Total Trades: {total_trades}",
                f"• Win Rate: {win_rate:.1f}%",
                f"• Avg Trade: {formatter.format_price_with_symbol(avg_trade)}",
                f"• Largest Win: {formatter.format_price_with_symbol(largest_win)}",
                f"• Largest Loss: {formatter.format_price_with_symbol(largest_loss)}"
            ])

            # Add recent trades if available
            recent_trades = token_performance.get('recent_trades', [])
            if recent_trades:
                performance_text.append("\n<b>Recent Trades:</b>")
                for trade in recent_trades[:5]:  # Show last 5 trades
                    side = trade.get('side', '').upper()
                    pnl = trade.get('pnl', 0)
                    pnl_emoji = "🟢" if pnl >= 0 else "🔴"
                    performance_text.append(
                        f"• {side}: {pnl_emoji} {formatter.format_price_with_symbol(pnl)} "
                        f"({trade.get('entry_price', 0)} → {trade.get('exit_price', 0)})"
                    )

            await self._reply(update, "\n".join(performance_text))

        except Exception as e:
            error_message = f"❌ Error showing token performance: {str(e)}"
            await self._reply(update, error_message)
            logger.error(f"Error in _show_token_performance: {e}")
