import logging
from telegram import Update
from telegram.ext import ContextTypes
from .base import InfoCommandsBase
from src.utils.token_display_formatter import get_formatter

logger = logging.getLogger(__name__)

class PriceCommands(InfoCommandsBase):
    """Handles all price-related commands."""

    async def price_command(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
        """Handle the /price command to show price information."""
        if not self._is_authorized(update):
            return

        try:
            # Check if a specific token was requested
            args = context.args
            if not args:
                await self._reply(update, "❌ Please specify a token. Example: /price BTC")
                return

            token = args[0].upper()
            market_data = self.trading_engine.get_market_data(token)
            
            if not market_data or not market_data.get('ticker'):
                await self._reply(update, f"❌ Could not fetch price data for {token}")
                return

            ticker = market_data['ticker']
            formatter = get_formatter()

            # Format price information
            price_text_parts = [f"💰 <b>{token} Price Information</b>"]

            # Current price
            current_price = float(ticker.get('last', 0))
            price_text_parts.append(f"\n📊 <b>Current Price:</b> {formatter.format_price_with_symbol(current_price, token)}")

            # 24h change
            change_24h = float(ticker.get('percentage', 0))
            change_emoji = "🟢" if change_24h >= 0 else "🔴"
            price_text_parts.append(f"📈 <b>24h Change:</b> {change_emoji} {change_24h:+.2f}%")

            # 24h high/low
            high_24h = float(ticker.get('high', 0))
            low_24h = float(ticker.get('low', 0))
            price_text_parts.append(f"📊 <b>24h Range:</b> {formatter.format_price_with_symbol(low_24h, token)} - {formatter.format_price_with_symbol(high_24h, token)}")

            # Volume
            volume_24h = float(ticker.get('quoteVolume', 0))
            price_text_parts.append(f"💎 <b>24h Volume:</b> {formatter.format_price_with_symbol(volume_24h)}")

            await self._reply(update, "\n".join(price_text_parts))

        except Exception as e:
            error_message = f"❌ Error processing price command: {str(e)}"
            await self._reply(update, error_message)
            logger.error(f"Error in price command: {e}") 